==> keycloak-model-map-hot-rod-20.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodPermissionTicketEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodPermissionTicketEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.PermissionTicket.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity.HotRodPermissionTicketEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodPermissionTicketEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodPermissionTicketEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.PermissionTicket.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodPermissionTicketEntity.HotRodPermissionTicketEntitySchema.INSTANCE;
    }
}
